"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const graphql_1 = require("graphql");
const language_1 = require("./language");
exports.builtInScalarMap = {
    [graphql_1.GraphQLString.name]: 'string',
    [graphql_1.GraphQLInt.name]: 'number',
    [graphql_1.GraphQLFloat.name]: 'number',
    [graphql_1.GraphQLBoolean.name]: 'boolean',
    [graphql_1.GraphQLID.name]: 'string',
};
function printInputGraphQLField(name, type, generator) {
    if (type === undefined || getRootGraphQLType(type) === undefined) {
        throw new Error(`An invalid type was provided for key '${name}'. This probably means there is a typo in your document or that one of your input types has been renamed.`);
    }
    language_1.printPropertyKey(name, !(type instanceof graphql_1.GraphQLNonNull), generator);
    printInputGraphQLType(type, generator);
    generator.print(',');
}
exports.printInputGraphQLField = printInputGraphQLField;
function printInputGraphQLType(type, generator) {
    let nullable = true;
    if (type instanceof graphql_1.GraphQLNonNull) {
        nullable = false;
        type = type.ofType;
    }
    if (type instanceof graphql_1.GraphQLList) {
        const subType = type.ofType;
        if (subType instanceof graphql_1.GraphQLNonNull) {
            printInputGraphQLType(type.ofType, generator);
        }
        else {
            generator.print('(');
            printInputGraphQLType(type.ofType, generator);
            generator.print(')');
        }
        generator.print('[]');
    }
    else if (exports.builtInScalarMap.hasOwnProperty(type.name)) {
        generator.print(exports.builtInScalarMap[type.name]);
    }
    else {
        generator.print(`Schema.${type.name}`);
    }
    generator.print(nullable && ' | null');
}
function printRootGraphQLType(type, generator) {
    if (type instanceof graphql_1.GraphQLInputObjectType) {
        language_1.printInterface({ name: type.name }, () => {
            const fields = type.getFields();
            Object.keys(fields).forEach((name) => {
                const field = fields[name];
                printInputGraphQLField(name, field.type, generator);
            });
        }, generator);
    }
    else if (type instanceof graphql_1.GraphQLEnumType) {
        const values = type.getValues();
        generator.print(`type ${type.name} = `);
        values.forEach((value, index) => {
            generator.print(`'${value.value}'`);
            generator.print(index !== values.length - 1 && ' | ');
        });
        generator.print(';');
    }
    else if (type instanceof graphql_1.GraphQLScalarType) {
        generator.print(`type ${type.name} = string;`);
    }
}
exports.printRootGraphQLType = printRootGraphQLType;
function getRootGraphQLType(type) {
    let finalType = type;
    while (finalType instanceof graphql_1.GraphQLNonNull || finalType instanceof graphql_1.GraphQLList) {
        finalType = finalType.ofType;
    }
    return finalType;
}
exports.getRootGraphQLType = getRootGraphQLType;
